${title}

title: %r" % value continue url, title = value.split(None, 1) links.append((name, url.strip(), title.strip())) links.sort() t.links = [(u, title) for (n, u, title) in links] ?>

# ${home_title}

- - ${doc_title}
  - Modules
  - Trac
  - Blog
  - Discuss
  - about ${home_title}
  - ${title}

This documentation is licensed under the ${license['title']}
built with pudge/${pudge.__version__} | original design by ratter / robert |